@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2010-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2010-2023 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -22,23 +22,12 @@
 #define __GLOBAL_H
 
 
-#define  PROGNAME       "jnoisemeter"
+#define  PROGNAME "jnoisemeter"
 
-#define  EV_X11         16
-#define  EV_EXIT        31
-
-#define  DCF_OFF        0
-#define  DCF_5HZ        1
-
-#define  FIL_NONE       0
-#define  FIL_20KHZ      1
-#define  FIL_IECA       2
-#define  FIL_IECC       3
-#define  FIL_ITU1       4
-#define  FIL_ITU2       5
-
-#define  DET_ITU        0
-#define  DET_RMS        1
-#define  DET_VUM        2
+enum { EV_X11 = 16, EV_EXIT = 31 };
+enum { DCF_OFF = 0, DCF_5HZ = 1 };
+enum { FIL_NONE, FIL_20KHZ, FIL_IECA, FIL_IECC, FIL_ITU1, FIL_ITU2, FIL_OCT };
+enum { DET_ITU, DET_RMS, DET_VUM };
+enum { ST_INI = 0, ST_ACT = 1, ST_ERR = -1 };
 
 #endif
