@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2010-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2010-2023 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ Jclient::Jclient (const char *jname, const char *jserv) :
     A_thread ("Jclient"),
     _jack_client (0),
     _jname (0),
-    _state (0),
+    _state (ST_INI),
     _input (0),
     _dcfilt (-1),
     _filter (-1),
@@ -70,13 +70,33 @@ void Jclient::init_jack (const char *jname, const char *jserv)
     _jname = jack_get_client_name (_jack_client);
     _fsamp = jack_get_sample_rate (_jack_client);
 
+    switch (_fsamp)
+    {
+    case 44100:
+	_oct1par = &Oct1filt44;
+	break;
+    case 48000:
+	_oct1par = &Oct1filt48;
+	break;
+    case 88200:
+	_oct1par = &Oct1filt88;
+	break;
+    case 96000:
+	_oct1par = &Oct1filt96;
+	break;
+    default:
+	_state = ST_ERR;
+	_oct1par = 0;
+	
+    }	
+
     for (i = 0; i < 8; i++)
     {
 	sprintf (s, "in_%d", i + 1);
         _inpports [i] = jack_port_register (_jack_client, s, JACK_DEFAULT_AUDIO_TYPE, JackPortIsInput, 0);
     }
     _outports [0] = jack_port_register (_jack_client, "out", JACK_DEFAULT_AUDIO_TYPE, JackPortIsOutput, 0);
-    _state = 1;
+    _state = ST_ACT;
 }
 
 
@@ -132,24 +152,33 @@ void Jclient::set_input (int input)
     _input = input;
 }
 
+
 void Jclient::set_filter (int filter)
 {
     if (_filter == filter) return;
-    switch (filter)
+    if (filter >= FIL_OCT)
     {
-    case FIL_20KHZ:
-	_lpefilter.init (_fsamp);
-	break;
-    case FIL_IECA:
-    case FIL_IECC:
-	_acwfilter.init (_fsamp);
-	break;
-    case FIL_ITU1:
-	_itufilter.init (_fsamp, false);
-	break;
-    case FIL_ITU2:
-	_itufilter.init (_fsamp, true);
-	break;
+	if (_oct1par) _bp6filter.setparam (&_oct1par->_param [filter - FIL_OCT]);
+	else          _bp6filter.setparam (0);
+    }
+    else
+    {
+	switch (filter)
+	{
+	case FIL_20KHZ:
+	    _lpefilter.init (_fsamp);
+	    break;
+	case FIL_IECA:
+	case FIL_IECC:
+	    _acwfilter.init (_fsamp);
+	    break;
+	case FIL_ITU1:
+	    _itufilter.init (_fsamp, false);
+	    break;
+	case FIL_ITU2:
+	    _itufilter.init (_fsamp, true);
+	    break;
+	}
     }
     _filter = filter;
 }
@@ -197,7 +226,7 @@ int Jclient::jack_process (int frames)
     float *inp;
     float *out;
 
-    if (_state == 0) return 0;
+    if (_state == ST_INI) return 0;
 
     inp = (float *) jack_port_get_buffer (_inpports [_input], frames);
     out = (float *) jack_port_get_buffer (_outports [0], frames);
@@ -218,23 +247,30 @@ int Jclient::jack_process (int frames)
 	memcpy (out, inp, frames * sizeof (float));
     }
 
-    switch (_filter)
+    if (_filter >= FIL_OCT)
     {
-    case FIL_20KHZ:
-	_lpefilter.process (frames, out, out);
-	break;
-    case FIL_IECA:
-	_acwfilter.process (frames, out, out, 0);
-	break;
-    case FIL_IECC:
-	_acwfilter.process (frames, out, 0, out);
-	break;
-    case FIL_ITU1:
-    case FIL_ITU2:
-	_itufilter.process (frames, out, out);
-	break;
+	_bp6filter.process (frames, out, out);
     }
-
+    else
+    {
+	switch (_filter)
+	{
+	case FIL_20KHZ:
+	    _lpefilter.process (frames, out, out);
+	    break;
+	case FIL_IECA:
+	    _acwfilter.process (frames, out, out, 0);
+	    break;
+	case FIL_IECC:
+	    _acwfilter.process (frames, out, 0, out);
+	    break;
+	case FIL_ITU1:
+	case FIL_ITU2:
+	    _itufilter.process (frames, out, out);
+	    break;
+	}
+    }
+    
     switch (_detect)
     {
     case DET_ITU:
