@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2010-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2010-2023 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 #include "acfilter.h"
 #include "lpeq20filter.h"
 #include "itu468filter.h"
+#include "iecfilt.h"
 #include "vumdetect.h"
 #include "rmsdetect.h"
 #include "itu468detect.h"
@@ -42,10 +43,11 @@ public:
 
     Jclient (const char *jname, const char *jserv);
     ~Jclient (void);
-  
+
+    const int state (void) const { return _state; }
     const char *jname (void) const { return _jname; }
     float get_value (void) const { return _val; }
-
+    
     void set_input (int input);
     void set_dcfilt (int dcfilt);
     void set_filter (int filter);
@@ -80,6 +82,8 @@ private:
     ACfilter        _acwfilter;
     LPeq20filter    _lpefilter;
     Itu468filter    _itufilter;
+    Bp6filter       _bp6filter;
+    Bp6paramset    *_oct1par;
     VUMdetect       _vumdetect;
     RMSdetect       _rmsdetect;
     Itu468detect    _itudetect;
