@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2010-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2010-2023 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -34,9 +34,9 @@
 
 
 XrmOptionDescRec options [NOPTS] =
-{
-    {CP"-h", CP".help",     XrmoptionNoArg,   CP"true" },
-    {CP"-n", CP".server",   XrmoptionSepArg,  0        }
+{  
+    {CP"-h", CP".help",      XrmoptionNoArg,   CP"true" },
+    {CP"-s", CP".server",    XrmoptionSepArg,  0        }
 };
 
 
@@ -48,10 +48,11 @@ static Mainwin  *mainwin = 0;
 static void help (void)
 {
     fprintf (stderr, "\n%s-%s\n\n", PROGNAME, VERSION);
-    fprintf (stderr, "  (C) 2010 Fons Adriaensen  <fons@kokkinizita.net>\n\n");
+    fprintf (stderr, "  (C) 2010-2023 Fons Adriaensen  <fons@linuxaudio.org>\n\n");
     fprintf (stderr, "Options:\n");
     fprintf (stderr, "  -h            Display this text\n");
-    fprintf (stderr, "  -n            Jack server name\n");
+    fprintf (stderr, "  -name <name>  Jack and X11 name\n");
+    fprintf (stderr, "  -s <server>   Select Jack server\n");
     exit (1);
 }
 
