@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2010-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2010-2023 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -27,7 +27,9 @@
 
 
 static const char *inp_text [] = { "1", "2", "3", "4", "5", "6", "7", "8" };
-static const char *fil_text [] = { "Flat", "20k", "A", "C", "ITU", "ITU2" };
+static const char *fil_text [] = { "Flat", "20k", "A", "C", "ITU", "ITU2",
+				   "32", "63", "125", "250", "500",
+				   "1k", "2k", "4k", "8k", "16k" };
 static const char *det_text [] = { "ITU", "RMS", "AV" };
 
 
@@ -62,6 +64,7 @@ Mainwin::Mainwin (X_rootwin *parent, X_resman *xres, int xp, int yp, Jclient *jc
     _t_disp = new X_textip (this, this, &tstyle2, 200, 2, 195, 43, 31);
     _t_disp->set_align (1);
     _t_disp->x_map ();
+    if (_jclient->state () == ST_ERR) _t_disp->set_text ("Err: FS ");
 
     bstyle1.size.x = 24;
     bstyle1.size.y = 17;
@@ -88,15 +91,20 @@ Mainwin::Mainwin (X_rootwin *parent, X_resman *xres, int xp, int yp, Jclient *jc
     _b_dcfilt = new X_tbutton (this, this, &bstyle1, x, y, "DC", 0, B_DCF);
     _b_dcfilt->x_map ();
     x += 50;
-    for (i = 0; i < 6; i++)
+    for (i = 0; i < 16; i++)
     {
         _b_filter [i] = new X_tbutton (this, this, &bstyle1, x, y, fil_text [i], 0, B_FIL + i);
         _b_filter [i]->x_map ();
-        x += 45;
+	if ((i == 5) || (i == 10))
+	{
+	    x -= 180;
+	    y += 19;
+	}
+	else x += 45;
     }
 
     x = 70;
-    y = 75;
+    y += 23;
     (new X_textln (this, &tstyle1, 10, y, 55, 17, "Detect", 0))->x_map ();
     _b_slower = new X_tbutton (this, this, &bstyle1, x, y, "Slow", 0, B_SLO);
     _b_slower->x_map ();
@@ -175,6 +183,7 @@ void Mainwin::handle_time (void)
     float v;
     char  s [16];
 
+    if (_jclient->state () == ST_ERR) return;
     v = _jclient->get_value ();
     if (v < 1e-10f) 
     {
@@ -199,47 +208,38 @@ void Mainwin::handle_stop (void)
 void Mainwin::handle_callb (int type, X_window *W, XEvent *E)
 {
     X_button *B;
-    int         k;
+    int       k;
 
-    switch (type)
+    if (type == (X_callback::BUTTON | X_button::PRESS))
     {
-    case X_callback::BUTTON | X_button::PRESS:
 	B = (X_button *) W;
 	k = B->cbid ();
-	switch (k)
+	if (k < B_FIL)
 	{
-	case B_INP + 0:
-	case B_INP + 1:
-	case B_INP + 2:
-	case B_INP + 3:
-	case B_INP + 4:
-	case B_INP + 5:
-	case B_INP + 6:
-	case B_INP + 7:
 	    set_input (k - B_INP);
-	    break;
-	case B_FIL + FIL_NONE:
-	case B_FIL + FIL_20KHZ:
-	case B_FIL + FIL_IECA:
-	case B_FIL + FIL_IECC:
-	case B_FIL + FIL_ITU1:
-	case B_FIL + FIL_ITU2:
+	    return;
+	}
+	if (k < B_DET)
+	{
 	    set_filter (k - B_FIL);
-	    break;
-	case B_DCF:
+	    return;
+	}
+	if (k < B_DCF)
+	{
+	    set_detect (k - B_DET);
+	    return;
+	}
+	if (k == B_DCF)
+	{
 	    B->set_stat (B->stat () ^ 2);
 	    _jclient->set_dcfilt (B->stat ());
-	    break;
-	case B_DET + DET_ITU:
-	case B_DET + DET_RMS:
-	case B_DET + DET_VUM:
-	    set_detect (k - B_DET);
-	    break;
-	case B_SLO:
+	    return;
+	}
+	if (k == B_SLO)
+	{
 	    B->set_stat (B->stat () ^ 2);
 	    _jclient->set_slower (B->stat ());
-	    break;
-	break;
+	    return;;
 	}
     }
 }
