@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2010-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2010-2023 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -41,8 +41,8 @@ public:
 
 private:
 
-    enum { XSIZE = 400, YSIZE = 100 };
-    enum { B_INP = 0, B_FIL = 10, B_DCF = 20, B_DET = 30, B_SLO = 40 };
+    enum { XSIZE = 400, YSIZE = 140 };
+    enum { B_INP = 0, B_FIL = 8, B_DET = 24, B_DCF = 27, B_SLO = 28 };
 
     virtual void thr_main (void) {}
 
@@ -62,9 +62,9 @@ private:
     X_resman       *_xres;
     Jclient        *_jclient;
     X_button       *_b_input [8];
-    X_button       *_b_dcfilt;
-    X_button       *_b_filter [6];
+    X_button       *_b_filter [16];
     X_button       *_b_detect [3];
+    X_button       *_b_dcfilt;
     X_button       *_b_slower;
     X_textip       *_t_disp;
     int             _input;
