@@ -46,7 +46,7 @@ void styles_init (X_display *disp, X_resman *xrm)
 
     XftFonts [F_TEXT] = disp->alloc_xftfont (xrm->get (".font.text", "luxi:bold:pixelsize=11"));
     XftFonts [F_BUTT] = disp->alloc_xftfont (xrm->get (".font.butt", "luxi:bold:pixelsize=11"));
-    XftFonts [F_DISP] = disp->alloc_xftfont (xrm->get (".font.disp", "luxi:bold:pixelsize=24"));
+    XftFonts [F_DISP] = disp->alloc_xftfont (xrm->get (".font.disp", "fira:bold:pixelsize=25"));
 
     tstyle1.font = XftFonts [F_TEXT];
     tstyle1.color.normal.bgnd = XftColors [C_MAIN_BG]->pixel;
